@@ -361,9 +361,8 @@ impl MenuItem {
     /// Set the image of the menu item
     /// # Safety
     /// Trying to add a label after adding an image might lead to undefined behavior
-    pub unsafe fn set_image<I: ImageExt>(&mut self, mut image: I) {
+    pub unsafe fn set_image<I: ImageExt>(&mut self, image: I) {
         assert!(!self.was_deleted());
-        image.increment_arc();
         Fl_Menu_Item_image(self.inner, image.as_image_ptr() as _)
     }
 }
